%% ncalls
% This programm aims to compare how many calls are produced (by one and the
% same bat) with different flow fields
% - echo-acoustic (1)
% - optic (2)
% - contraditcting echo-acoustic and optic (3)
% As we only have asymetric conditions recorded with (3), we compare # of
% calls only for trials in asymetric flow conditions.
% Bats used in all three experiments are:
% - Luanne (Bat 2 in (2+3); Bat 4 with BROAD (1.1) and FINE (1.2) panels)
% - Speedy (Bat 3 in (2+3); Bat 7 with FINE panel (1.2))
% - Rocket (Bat 4 in (2+3); Bat 3 with BROAD panel (1.1))
% - General Ticktack (Bat 5 in (2+3); Bat 6 With BROAD (1.1)) and FINE (1.2)
% panels)

clear all
close all

datasets={'EAF','OF','OFvsEAF'};
EAFdirs = {'../acousticsdata/EAF_broadpaneldata/',...
    '../acousticsdata/EAF_finepaneldata/'};
OFandOFvsEAFdir = {'../acousticsdata/EAFvsOF_data/'};
% dataset_ind = menu('which data set do you want to analyse?', ...
%     'echo-acoustic flow', 'optic flow', 'optic vs acoustic flow');

bats = {'LUANNE', 'SPEEDY', 'ROCKET', 'TICKTACK'};


% preallocate variables;
ncalls_EAF_OF_EAFvsOF = cell(numel(bats),3);  % Rows are bats as ordered in the
%                                             % variable 'bats'. Columns is Flow
calllevels = cell(numel(bats),3);             % for call levels

% Matrix that shows how many trials the bats did with which flow field
bat_ntrials = NaN(numel(bats),3);
bat_ncalls = NaN(numel(bats),3);

% check for plot
scrsz=get(0,'screensize');
for dsc = 1:numel(datasets),
    dataset_ind = dsc;
    % preallocate variables:
    datasetdirs = cell(numel(bats),1);
    
    % chose the correct data directory:
    if dataset_ind == 1,
        % find bat where we need to compare with fine panel data because broad
        % panel is not available: Speedy
        finepanelbat_ind = find(arrayfun(@(x) strcmp(x,'SPEEDY'), bats));
        [datasetdirs{:}] = deal(EAFdirs{1});
        datasetdirs{finepanelbat_ind} = deal(EAFdirs{2});
        datasetstr = '';
        connector = '';
        batnumbers=[4 7 3 6];
    elseif dataset_ind > 1,
        [datasetdirs{:}] = deal(OFandOFvsEAFdir);
        connector = '_';
        batnumbers=[2 3 4 5];
        if dataset_ind == 2,
            datasetstr = 'OF';
        elseif dataset_ind == 3,
            datasetstr = 'OFvsEAF';
        end
    end
    
    for bc = 1:numel(bats),
        clear result*
        bat=bats{bc};
        batnum=batnumbers(bc);
        % load results from acoustic raw data analysis; this CANNOT be done
        % before this loop, because we take the data from different data
        % sets in some cases
        acousticsdir = char(datasetdirs{bc});
        load([acousticsdir 'callana_allbats' connector datasetstr '.mat'])
        % pool all calls produced within asymmetric walls together
        asym_vars = whos('results*asym*');
        asym_vars = {asym_vars.name}';
        all_asym_audio = [eval(asym_vars{1}) eval(asym_vars{2}) ...
            eval(asym_vars{3}) eval(asym_vars{4})];
        % identify all entries for calls of the current bat with 'asymmetric conditions'; pool all of
        % them together
        batinds=find(all_asym_audio(1,:)==batnum);
        batasyms=all_asym_audio(:,batinds);
        % check how many files and with how many calls each are in there
        battrials=unique(batasyms(2,:));
        bat_ntrials(bc,dsc) = numel(battrials);
        % check how many calls were produced in each file / trial
        callns=[];
        for cc=1:bat_ntrials(bc,dsc)
            battrial = battrials(cc);   % find next trial number
            trialinds = find(batasyms(2,:)==battrial);
            calln = numel(find(trialinds)); % check how many entries
            % if only one entry: check if a call has been produced at all;
            % if this is not the case, lines 3-8 will be NaN entries
            if calln == 1,
                % if max level is NaN entry, set calln to zero
                if isnan(batasyms(6,trialinds)),
                    calln = 0;
                end
            end
            % add number of calls to matrix
            callns=[callns calln];
        end
        bat_ncalls(bc,dsc)=sum(callns);
        ncalls_EAF_OF_EAFvsOF{bc,dsc}=callns;
        
        % get call levels
        calllevels{bc,dsc}=batasyms(6,:);
    end
end

% visualize
figure(1), hold on
set(gcf,'position',[scrsz(3)*2/5 1 scrsz(3)*1/5 scrsz(4)])
figure(2), hold on
set(gcf,'position',[scrsz(3)*3/5 1 scrsz(3)*1/5 scrsz(4)])
figure(3), hold on
set(gcf,'position',[0 1 scrsz(3)*2/5 scrsz(4)])
figure(4), hold on
set(gcf,'position',[scrsz(3)*3/5 1 scrsz(3)*2/5 scrsz(4)])
for bc = 1:numel(bats),
    % get data into 'boxplotable' format
    batboxplotmatrix = NaN(max(bat_ntrials(bc,:)),3);
    for cc = 1:numel(datasets),
        batboxplotmatrix(1:bat_ntrials(bc,cc),cc)=ncalls_EAF_OF_EAFvsOF{bc,cc};
    end
    figure(1)
    subplot(numel(bats),1,bc), hold on,
    set(gca,'ytick',[0:5:20],'ygrid','on')
    boxplot(batboxplotmatrix,'notch','on'),
    set(gca,'xtick',1:3,'xticklabel',datasets,'ylim',[0 20])
    ylabel(bats(bc))
    if bc == 1,
        title('# of calls with different flow fields','fontweight','bold',...
            'fontsize',14)
    end
    % calculate median and interquartiles
    bat_calln_medians(bc,1:3) = prctile(batboxplotmatrix,50);
    bat_calln_25(bc,1:3) = prctile(batboxplotmatrix,25);
    bat_calln_75(bc,1:3) = prctile(batboxplotmatrix,75);
    
    % call level figure
    calllevelboxplotmatrix = NaN(max(bat_ncalls(bc,:)),2);
    for cc = 2:numel(datasets),
        calllevelboxplotmatrix(1:bat_ncalls(bc,cc),cc-1)=calllevels{bc,cc};
    end
    figure(2), hold on
    subplot(numel(bats),1,bc), hold on,
    set(gca,'ytick',[-10:10:25],'ygrid','on')
    boxplot(calllevelboxplotmatrix,'notch','on'),
    set(gca,'xtick',1:3,'xticklabel',datasets(2:3),'ylim',[-13 30])
    ylabel(bats(bc))
    if bc == 1,
        title('call level of call onset (dB full scale)','fontweight','bold',...
            'fontsize',14)
    end
    % calculate median call level and interquartiles
    bat_calllvl_medians(bc,1:2) = prctile(calllevelboxplotmatrix,50);
    bat_calllvl_25(bc,1:2) = prctile(calllevelboxplotmatrix,25);
    bat_calllvl_75(bc,1:2) = prctile(calllevelboxplotmatrix,75);
end


%     statistics
for bc = 1:numel(bats),
    bat = ['Bat' bats(bc)];
    
    %% 1. Number of calls
    % reorder data
    %         allNs = [ncalls_EAF_OF_EAFvsOF{bc,1} ncalls_EAF_OF_EAFvsOF{bc,2} ncalls_EAF_OF_EAFvsOF{bc,3}];
    %         identities = [ones(1,bat_ntrials(bc,1)), 2*ones(1,bat_ntrials(bc,2)), 3*ones(1,bat_ntrials(bc,3))];
    % test if EAF and OF differ
    [P_allN_EAF_OF(bc,1), H_allN_EAF_OF(bc,1)] = ranksum(ncalls_EAF_OF_EAFvsOF{bc,1}, ncalls_EAF_OF_EAFvsOF{bc,2});
    [P_allN_EAF_EAFvsOF(bc,1), H_allN_EAF_EAFvsOF(bc,1)] = ranksum(ncalls_EAF_OF_EAFvsOF{bc,1}, ncalls_EAF_OF_EAFvsOF{bc,3});
    [P_allN_OF_EAFvsOF(bc,1), H_allN_OF_EAFvsOF(bc,1)] = ranksum(ncalls_EAF_OF_EAFvsOF{bc,2}, ncalls_EAF_OF_EAFvsOF{bc,3});
    
    %% 2. Call levels
    [P_calls_OF_OFvsEAF(bc,1), H_calls_OF_OFvsEAF(bc,1)] = ranksum(calllevels{bc,2}, calllevels{bc,3});
    
    figure(3),
    subplot(4,2,bc*2-1), hold on
    hist(calllevels{bc,2})
    l1=line(ones(1,2)*bat_calllvl_medians(bc,1),[0,150],'color','r',...
        'linestyle','--','linewidth',2);
    set(gca,'xlim',[-15 25],'ylim',[0 130])
    hh1 = findobj(gca,'Type','patch');
    xlabel('call level (db full scale)')
    ylabel('# of incidences')
    subplot(4,2,bc*2), hold on
    hist(calllevels{bc,3})
    l2=line(ones(1,2)*bat_calllvl_medians(bc,2),[0,150],'color','r',...
        'linestyle','--','linewidth',2);
    set(gca,'xlim',[-15 25],'ylim',[0 130])
    hh2 = findobj(gca,'Type','patch');
    xlabel('call level (db full scale)')
    ylabel(bats{bc})
    [t,th]=suplabel('call level histogram','t');
    set(th,'fontweight','bold','fontsize',14)
    set([hh1,hh2],'FaceColor',[0 0.7 0],'EdgeColor','w','facealpha',0.5)
    
    figure(4)
    subplot(4,3,bc*3-2), hold on
    if bc == 1, title(datasets{1}), end
    
    hist(ncalls_EAF_OF_EAFvsOF{bc,1},0:1:20)
    if bc == numel(bats), xlabel('# of calls'), end
    line(ones(1,2)*bat_calln_medians(bc,1),[0,150],'color','r',...
        'linestyle','--','linewidth',2);
    ylabel('# of incidences')
    set(gca,'xlim',[0 20],'ylim',[0 20])
    subplot(4,3,bc*3-1), hold on
    if bc == 1, title(datasets{2}), end
    
    hist(ncalls_EAF_OF_EAFvsOF{bc,2},0:1:20)
    line(ones(1,2)*bat_calln_medians(bc,2),[0,150],'color','r',...
        'linestyle','--','linewidth',2);
    set(gca,'xlim',[0 20],'ylim',[0 20])
    if bc == numel(bats), xlabel('# of calls'), end
    subplot(4,3,bc*3), hold on
    if bc == 1, title(datasets{3}), end
    
    hist(ncalls_EAF_OF_EAFvsOF{bc,3},0:1:20)
    line(ones(1,2)*bat_calln_medians(bc,3),[0,150],'color','r',...
        'linestyle','--','linewidth',2);
    set(gca,'xlim',[0 20],'ylim',[0 20])
    set(gca,'yaxislocation','right');
    ylabel(bats{bc})
    if bc == numel(bats), xlabel('# of calls'), end
    [t2,th2]=suplabel('# of calls - histograms', 't');
    set(th2,'fontweight','bold','fontsize',14)
end