%% figure_number_of_calls.m
% Bats correspond to the following:
% - Luanne (Bat 2 in (2+3); Bat 4 with BROAD (1.1) and FINE (1.2) panels)
% - Speedy (Bat 3 in (2+3); Bat 7 with FINE panel (1.2))
% - Rocket (Bat 4 in (2+3); Bat 3 with BROAD panel (1.1))
% - General Ticktack (Bat 5 in (2+3); Bat 6 With BROAD (1.1)) and FINE (1.2)
% panels)
clear all
close all

save_on=1;
errorbarcolors = 1;

load('../acousticsdata/ncalls_different_datasets.mat')
load('../acousticsdata/trial_and_calln.mat')
bat_numbers = [4 7 3 6];
[bat_numbers_sorted,bat_inds]=sort(bat_numbers,'ascend');
figure(1), hold on;
bh=bar(bat_inds,bat_calln_medians,1);
bh(1).FaceColor = 'b';
bh(2).FaceColor = [1 .6 0.07];
bh(3).FaceColor = 'k';
versatz = .22;
X = [bat_inds'-versatz, bat_inds', bat_inds'+versatz];
Y = bat_calln_medians;
L = bat_calln_medians-bat_calln_25;
U = bat_calln_75 - bat_calln_medians;
linecolor = [.6 .6 .6];
markercolor = [.7 .7 .7];
if errorbarcolors == 1,
    eh=errorbar(X,Y,L,U, 'o','Markerfacecolor',linecolor,'Linewidth',1.8,'Markersize',5);
    [eh.Color]=deal([linecolor]);
elseif errorbarcolors == 2,
    eh1=errorbar(X,Y,L,zeros(size(U)), 'o','Markerfacecolor',markercolor,...
        'Markeredgecolor',markercolor,'Linewidth',1.8,'Markersize',5);
    [eh1.Color]=deal([1 1 1]);
    eh2=errorbar(X,Y,zeros(size(L)),U, 'o','Markerfacecolor',markercolor,...
        'Markeredgecolor',markercolor,'Linewidth',1.8);
    % [eh2.Color]=deal([0 0 0]);
    [eh2.Color]=deal(linecolor);
end
% add trial and call numbers
for ffc = 1:numel(datasets),
    for bc = 1:numel(bats),
        th=text(X(bc,ffc),1,...
            [num2str(bat_ntrials(bc,ffc)) ' / ' num2str(bat_ncalls(bc,ffc))]...
            ,'color',[1 1 1]);
        set(th,'rotation',90)
    end
end

set(gca,'xtick',1:4, 'xticklabel', ...
    arrayfun(@(x) ['Bat ' num2str(x)], bat_numbers_sorted,'UniformOutput',0))
ylabel({'# of calls per flight', ' emitted in the central 2 m of the tunnel'})
legend('echo-acoustic flow','optic flow','contradicting optic and echo-acoustic flow',...
    'location','NorthWest')
legend('boxoff')
% save quickly
% export_fig(['../figures/ncalls_figure_V' num2str(errorbarcolors)  '.jpg'])
fig_dimensions = [8 6];
rect = [0 0 fig_dimensions];
% set(gcf,'Units','centimeters','PaperUnits','centimeter',...'Outerposition',rect,...
%     'Position',rect,'PaperPosition',rect,'PaperSize',fig_dimensions,...
%     'color',[1 1 1]); hold on; axis off;
curr_y_lim=get(gca,'ylim');
% set(gca,'ylim', curr_y_lim + [0 5]);
set(gcf,'color',[1 1 1]);
if save_on==1,
    export_fig(['../figures/ncalls_figure_V' num2str(errorbarcolors)  '.jpg'],...
        '-nocrop','-q100','-m1.5')
end
% ax = gca;
% c = ax.Color;
% ax.Color = 'k';
% savedir='../figures/';
% print(gcf,[savedir 'ncalls_plot'],'-djpeg','-r1200')